@@ -36,9 +36,11 @@
 
 
 #include <urdf_model_state/model_state.h>
+#include <urdf_model/utils.h>
 #include <fstream>
 #include <sstream>
-#include <boost/lexical_cast.hpp>
+#include <stdexcept>
+#include <string>
 #include <algorithm>
 #include <tinyxml.h>
 #include <console_bridge/console.h>
@@ -61,13 +63,17 @@ bool parseModelState(ModelState &ms, TiXmlElement* config)
   if (time_stamp_char)
   {
     try {
-      double sec = boost::lexical_cast<double>(time_stamp_char);
+      double sec = std::stod(time_stamp_char);
       ms.time_stamp.set(sec);
     }
-    catch (boost::bad_lexical_cast &e) {
+    catch (std::invalid_argument &e) {
       CONSOLE_BRIDGE_logError("Parsing time stamp [%s] failed: %s", time_stamp_char, e.what());
       return false;
     }
+    catch (std::out_of_range &e) {
+      CONSOLE_BRIDGE_logError("Parsing time stamp [%s] failed, out of range: %s", time_stamp_char, e.what());
+      return false;
+    }
   }
 
   TiXmlElement *joint_state_elem = config->FirstChildElement("joint_state");
@@ -91,15 +97,18 @@ bool parseModelState(ModelState &ms, TiXmlElement* config)
     {
 
       std::vector<std::string> pieces;
-      boost::split( pieces, position_char, boost::is_any_of(" "));
+      urdf::split_string( pieces, position_char, " ");
       for (unsigned int i = 0; i < pieces.size(); ++i){
         if (pieces[i] != ""){
           try {
-            joint_state->position.push_back(boost::lexical_cast<double>(pieces[i].c_str()));
+            joint_state->position.push_back(std::stod(pieces[i].c_str()));
           }
-          catch (boost::bad_lexical_cast &/*e*/) {
+          catch (std::invalid_argument &/*e*/) {
             throw ParseError("position element ("+ pieces[i] +") is not a valid float");
           }
+          catch (std::out_of_range &/*e*/) {
+            throw ParseError("position element ("+ pieces[i] +") is out of range");
+          }
         }
       }
     }
@@ -110,15 +119,18 @@ bool parseModelState(ModelState &ms, TiXmlElement* config)
     {
 
       std::vector<std::string> pieces;
-      boost::split( pieces, velocity_char, boost::is_any_of(" "));
+      urdf::split_string( pieces, velocity_char, " ");
       for (unsigned int i = 0; i < pieces.size(); ++i){
         if (pieces[i] != ""){
           try {
-            joint_state->velocity.push_back(boost::lexical_cast<double>(pieces[i].c_str()));
+            joint_state->velocity.push_back(std::stod(pieces[i].c_str()));
           }
-          catch (boost::bad_lexical_cast &/*e*/) {
+          catch (std::invalid_argument &/*e*/) {
             throw ParseError("velocity element ("+ pieces[i] +") is not a valid float");
           }
+          catch (std::out_of_range &/*e*/) {
+            throw ParseError("velocity element ("+ pieces[i] +") is out of range");
+          }
         }
       }
     }
@@ -129,15 +141,18 @@ bool parseModelState(ModelState &ms, TiXmlElement* config)
     {
 
       std::vector<std::string> pieces;
-      boost::split( pieces, effort_char, boost::is_any_of(" "));
+      urdf::split_string( pieces, effort_char, " ");
       for (unsigned int i = 0; i < pieces.size(); ++i){
         if (pieces[i] != ""){
           try {
-            joint_state->effort.push_back(boost::lexical_cast<double>(pieces[i].c_str()));
+            joint_state->effort.push_back(std::stod(pieces[i].c_str()));
           }
-          catch (boost::bad_lexical_cast &/*e*/) {
+          catch (std::invalid_argument &/*e*/) {
             throw ParseError("effort element ("+ pieces[i] +") is not a valid float");
           }
+          catch (std::out_of_range &/*e*/) {
+            throw ParseError("effort element ("+ pieces[i] +") is out of range");
+          }
         }
       }
     }
