@@ -38,7 +38,8 @@
 #include <urdf_sensor/sensor.h>
 #include <fstream>
 #include <sstream>
-#include <boost/lexical_cast.hpp>
+#include <stdexcept>
+#include <string>
 #include <algorithm>
 #include <tinyxml.h>
 #include <console_bridge/console.h>
@@ -60,13 +61,18 @@ bool parseCamera(Camera &camera, TiXmlElement* config)
     {
       try
       {
-        camera.width = boost::lexical_cast<unsigned int>(width_char);
+        camera.width = std::stoul(width_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Camera image width [%s] is not a valid int: %s", width_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Camera image width [%s] is out of range: %s", width_char, e.what());
+        return false;
+      }
     }
     else
     {
@@ -79,13 +85,18 @@ bool parseCamera(Camera &camera, TiXmlElement* config)
     {
       try
       {
-        camera.height = boost::lexical_cast<unsigned int>(height_char);
+        camera.height = std::stoul(height_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Camera image height [%s] is not a valid int: %s", height_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Camera image height [%s] is out of range: %s", height_char, e.what());
+        return false;
+      }
     }
     else
     {
@@ -107,13 +118,18 @@ bool parseCamera(Camera &camera, TiXmlElement* config)
     {
       try
       {
-        camera.hfov = boost::lexical_cast<double>(hfov_char);
+        camera.hfov = std::stod(hfov_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Camera image hfov [%s] is not a valid float: %s", hfov_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Camera image hfov [%s] is out of range: %s", hfov_char, e.what());
+        return false;
+      }
     }
     else
     {
@@ -126,13 +142,18 @@ bool parseCamera(Camera &camera, TiXmlElement* config)
     {
       try
       {
-        camera.near = boost::lexical_cast<double>(near_char);
+        camera.near = std::stod(near_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Camera image near [%s] is not a valid float: %s", near_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Camera image near [%s] is out of range: %s", near_char, e.what());
+        return false;
+      }
     }
     else
     {
@@ -145,13 +166,18 @@ bool parseCamera(Camera &camera, TiXmlElement* config)
     {
       try
       {
-        camera.far = boost::lexical_cast<double>(far_char);
+        camera.far = std::stod(far_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Camera image far [%s] is not a valid float: %s", far_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Camera image far [%s] is out of range: %s", far_char, e.what());
+        return false;
+      }
     }
     else
     {
@@ -181,13 +207,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.horizontal_samples = boost::lexical_cast<unsigned int>(samples_char);
+        ray.horizontal_samples = std::stoul(samples_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray horizontal samples [%s] is not a valid float: %s", samples_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray horizontal samples [%s] is out of range: %s", samples_char, e.what());
+        return false;
+      }
     }
 
     const char* resolution_char = horizontal->Attribute("resolution");
@@ -195,13 +226,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.horizontal_resolution = boost::lexical_cast<double>(resolution_char);
+        ray.horizontal_resolution = std::stod(resolution_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray horizontal resolution [%s] is not a valid float: %s", resolution_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray horizontal resolution [%s] is out of range: %s", resolution_char, e.what());
+        return false;
+      }
     }   
     
     const char* min_angle_char = horizontal->Attribute("min_angle");
@@ -209,13 +245,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.horizontal_min_angle = boost::lexical_cast<double>(min_angle_char);
+        ray.horizontal_min_angle = std::stod(min_angle_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray horizontal min_angle [%s] is not a valid float: %s", min_angle_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray horizontal min_angle [%s] is out of range: %s", min_angle_char, e.what());
+        return false;
+      }
     }
 
     const char* max_angle_char = horizontal->Attribute("max_angle");
@@ -223,13 +264,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.horizontal_max_angle = boost::lexical_cast<double>(max_angle_char);
+        ray.horizontal_max_angle = std::stod(max_angle_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray horizontal max_angle [%s] is not a valid float: %s", max_angle_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray horizontal max_angle [%s] is out of range: %s", max_angle_char, e.what());
+        return false;
+      }
     }
   }
   
@@ -241,13 +287,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.vertical_samples = boost::lexical_cast<unsigned int>(samples_char);
+        ray.vertical_samples = std::stoul(samples_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray vertical samples [%s] is not a valid float: %s", samples_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray vertical samples [%s] is out of range: %s", samples_char, e.what());
+        return false;
+      }
     }
 
     const char* resolution_char = vertical->Attribute("resolution");
@@ -255,13 +306,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.vertical_resolution = boost::lexical_cast<double>(resolution_char);
+        ray.vertical_resolution = std::stod(resolution_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray vertical resolution [%s] is not a valid float: %s", resolution_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray vertical resolution [%s] is out of range: %s", resolution_char, e.what());
+        return false;
+      }
     }   
     
     const char* min_angle_char = vertical->Attribute("min_angle");
@@ -269,13 +325,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.vertical_min_angle = boost::lexical_cast<double>(min_angle_char);
+        ray.vertical_min_angle = std::stod(min_angle_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray vertical min_angle [%s] is not a valid float: %s", min_angle_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray vertical min_angle [%s] is out of range: %s", min_angle_char, e.what());
+        return false;
+      }
     }
 
     const char* max_angle_char = vertical->Attribute("max_angle");
@@ -283,13 +344,18 @@ bool parseRay(Ray &ray, TiXmlElement* config)
     {
       try
       {
-        ray.vertical_max_angle = boost::lexical_cast<double>(max_angle_char);
+        ray.vertical_max_angle = std::stod(max_angle_char);
       }
-      catch (boost::bad_lexical_cast &e)
+      catch (std::invalid_argument &e)
       {
         CONSOLE_BRIDGE_logError("Ray vertical max_angle [%s] is not a valid float: %s", max_angle_char, e.what());
         return false;
       }
+      catch (std::out_of_range &e)
+      {
+        CONSOLE_BRIDGE_logError("Ray vertical max_angle [%s] is out of range: %s", max_angle_char, e.what());
+        return false;
+      }
     }
   }
   return false;
